[PATCH 8/20] Re: [2.6-BK-URL] NTFS 2.1.17 release

From: Anton Altaparmakov
Date: Mon Aug 23 2004 - 05:48:53 EST


This is patch 8/20 in the series. It contains the following ChangeSet:

<aia21@xxxxxxxxxx> (04/07/21 1.1811)
NTFS: Rename map_runlist() to ntfs_map_runlist().

Signed-off-by: Anton Altaparmakov <aia21@xxxxxxxxxx>

Best regards,

Anton
--
Anton Altaparmakov <aia21 at cam.ac.uk> (replace at with @)
Unix Support, Computing Service, University of Cambridge, CB2 3QH, UK
Linux NTFS maintainer / IRC: #ntfs on irc.freenode.net
WWW: http://linux-ntfs.sf.net/, http://www-stu.christs.cam.ac.uk/~aia21/

===================================================================

diff -Nru a/fs/ntfs/aops.c b/fs/ntfs/aops.c
--- a/fs/ntfs/aops.c 2004-08-18 20:50:10 +01:00
+++ b/fs/ntfs/aops.c 2004-08-18 20:50:10 +01:00
@@ -260,7 +260,7 @@
* the duration.
*/
up_read(&ni->runlist.lock);
- if (!map_runlist(ni, vcn))
+ if (!ntfs_map_runlist(ni, vcn))
goto lock_retry_remap;
rl = NULL;
}
@@ -667,7 +667,7 @@
* the duration.
*/
up_read(&ni->runlist.lock);
- err = map_runlist(ni, vcn);
+ err = ntfs_map_runlist(ni, vcn);
if (likely(!err))
goto lock_retry_remap;
rl = NULL;
@@ -1443,7 +1443,7 @@
* lock for the duration.
*/
up_read(&ni->runlist.lock);
- err = map_runlist(ni, vcn);
+ err = ntfs_map_runlist(ni, vcn);
if (likely(!err))
goto lock_retry_remap;
rl = NULL;
diff -Nru a/fs/ntfs/attrib.h b/fs/ntfs/attrib.h
--- a/fs/ntfs/attrib.h 2004-08-18 20:50:10 +01:00
+++ b/fs/ntfs/attrib.h 2004-08-18 20:50:10 +01:00
@@ -75,7 +75,7 @@
extern runlist_element *decompress_mapping_pairs(const ntfs_volume *vol,
const ATTR_RECORD *attr, runlist_element *old_rl);

-extern int map_runlist(ntfs_inode *ni, VCN vcn);
+extern int ntfs_map_runlist(ntfs_inode *ni, VCN vcn);

extern LCN vcn_to_lcn(const runlist_element *rl, const VCN vcn);

diff -Nru a/fs/ntfs/compress.c b/fs/ntfs/compress.c
--- a/fs/ntfs/compress.c 2004-08-18 20:50:10 +01:00
+++ b/fs/ntfs/compress.c 2004-08-18 20:50:10 +01:00
@@ -621,7 +621,7 @@
* duration.
*/
up_read(&ni->runlist.lock);
- if (!map_runlist(ni, vcn))
+ if (!ntfs_map_runlist(ni, vcn))
goto lock_retry_remap;
goto map_rl_err;
}
@@ -920,8 +920,8 @@
goto err_out;

map_rl_err:
- ntfs_error(vol->sb, "map_runlist() failed. Cannot read compression "
- "block.");
+ ntfs_error(vol->sb, "ntfs_map_runlist() failed. Cannot read "
+ "compression block.");
goto err_out;

rl_err:
-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/
diff -Nru a/fs/ntfs/attrib.c b/fs/ntfs/attrib.c
--- a/fs/ntfs/attrib.c 2004-08-18 20:50:10 +01:00
+++ b/fs/ntfs/attrib.c 2004-08-18 20:50:10 +01:00
@@ -932,7 +932,7 @@
}

/**
* map_runlist - map (a part of) a run list of an ntfs inode
* @ni: ntfs inode for which to map (part of) a run list
* @vcn: map run list part containing this vcn
*
@@ -940,7 +940,7 @@
*
* Return 0 on success and -errno on error.
*/
-int map_runlist(ntfs_inode *ni, VCN vcn)
+int ntfs_map_runlist(ntfs_inode *ni, VCN vcn)
{
ntfs_inode *base_ni;
attr_search_context *ctx;
@@ -932,7 +932,7 @@

/**
- * map_runlist - map (a part of) a run list of an ntfs inode
+ * ntfs_map_runlist - map (a part of) a run list of an ntfs inode
* @ni: ntfs inode for which to map (part of) a run list
* @vcn: map run list part containing this vcn